/* abstract-field-details.c generated by valac 0.24.0.16-c045, the Vala compiler
 * generated from abstract-field-details.vala, do not modify */

/*
 * Copyright (C) 2011 Collabora Ltd.
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors: Travis Reitter <travis.reitter@collabora.co.uk>
 */

#include <glib.h>
#include <glib-object.h>
#include <folks-test.h>
#include <stdlib.h>
#include <string.h>
#include <folks/folks.h>
#include <gee.h>


#define TYPE_EMAIL_FIELD_DETAILS_TESTS (email_field_details_tests_get_type ())
#define EMAIL_FIELD_DETAILS_TESTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_EMAIL_FIELD_DETAILS_TESTS, EmailFieldDetailsTests))
#define EMAIL_FIELD_DETAILS_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_EMAIL_FIELD_DETAILS_TESTS, EmailFieldDetailsTestsClass))
#define IS_EMAIL_FIELD_DETAILS_TESTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_EMAIL_FIELD_DETAILS_TESTS))
#define IS_EMAIL_FIELD_DETAILS_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_EMAIL_FIELD_DETAILS_TESTS))
#define EMAIL_FIELD_DETAILS_TESTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_EMAIL_FIELD_DETAILS_TESTS, EmailFieldDetailsTestsClass))

typedef struct _EmailFieldDetailsTests EmailFieldDetailsTests;
typedef struct _EmailFieldDetailsTestsClass EmailFieldDetailsTestsClass;
typedef struct _EmailFieldDetailsTestsPrivate EmailFieldDetailsTestsPrivate;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define __g_list_free__g_free0_0(var) ((var == NULL) ? NULL : (var = (_g_list_free__g_free0_ (var), NULL)))
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _EmailFieldDetailsTests {
	FolksTestCase parent_instance;
	EmailFieldDetailsTestsPrivate * priv;
};

struct _EmailFieldDetailsTestsClass {
	FolksTestCaseClass parent_class;
};


static gpointer email_field_details_tests_parent_class = NULL;

GType email_field_details_tests_get_type (void) G_GNUC_CONST;
enum  {
	EMAIL_FIELD_DETAILS_TESTS_DUMMY_PROPERTY
};
EmailFieldDetailsTests* email_field_details_tests_new (void);
EmailFieldDetailsTests* email_field_details_tests_construct (GType object_type);
void email_field_details_tests_test_param_replacement (EmailFieldDetailsTests* self);
static void _email_field_details_tests_test_param_replacement_folks_test_case_test_method (gpointer self);
void email_field_details_tests_test_simple_equality (EmailFieldDetailsTests* self);
static void _email_field_details_tests_test_simple_equality_folks_test_case_test_method (gpointer self);
void email_field_details_tests_test_params_equality (EmailFieldDetailsTests* self);
static void _email_field_details_tests_test_params_equality_folks_test_case_test_method (gpointer self);
void email_field_details_tests_test_im_field_details_equality (EmailFieldDetailsTests* self);
static void _email_field_details_tests_test_im_field_details_equality_folks_test_case_test_method (gpointer self);
void email_field_details_tests_test_role_field_details_equality (EmailFieldDetailsTests* self);
static void _email_field_details_tests_test_role_field_details_equality_folks_test_case_test_method (gpointer self);
void email_field_details_tests_test_generic_afd_handling (EmailFieldDetailsTests* self);
static void _email_field_details_tests_test_generic_afd_handling_folks_test_case_test_method (gpointer self);
static void _g_free0_ (gpointer var);
static void _g_list_free__g_free0_ (GList* self);
gint _vala_main (gchar** args, int args_length1);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);


static void _email_field_details_tests_test_param_replacement_folks_test_case_test_method (gpointer self) {
#line 28 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	email_field_details_tests_test_param_replacement ((EmailFieldDetailsTests*) self);
#line 88 "abstract-field-details.c"
}


static void _email_field_details_tests_test_simple_equality_folks_test_case_test_method (gpointer self) {
#line 29 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	email_field_details_tests_test_simple_equality ((EmailFieldDetailsTests*) self);
#line 95 "abstract-field-details.c"
}


static void _email_field_details_tests_test_params_equality_folks_test_case_test_method (gpointer self) {
#line 30 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	email_field_details_tests_test_params_equality ((EmailFieldDetailsTests*) self);
#line 102 "abstract-field-details.c"
}


static void _email_field_details_tests_test_im_field_details_equality_folks_test_case_test_method (gpointer self) {
#line 31 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	email_field_details_tests_test_im_field_details_equality ((EmailFieldDetailsTests*) self);
#line 109 "abstract-field-details.c"
}


static void _email_field_details_tests_test_role_field_details_equality_folks_test_case_test_method (gpointer self) {
#line 33 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	email_field_details_tests_test_role_field_details_equality ((EmailFieldDetailsTests*) self);
#line 116 "abstract-field-details.c"
}


static void _email_field_details_tests_test_generic_afd_handling_folks_test_case_test_method (gpointer self) {
#line 35 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	email_field_details_tests_test_generic_afd_handling ((EmailFieldDetailsTests*) self);
#line 123 "abstract-field-details.c"
}


EmailFieldDetailsTests* email_field_details_tests_construct (GType object_type) {
	EmailFieldDetailsTests * self = NULL;
#line 27 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	self = (EmailFieldDetailsTests*) folks_test_case_construct (object_type, "EmailFieldDetails");
#line 28 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "parameter replacement", _email_field_details_tests_test_param_replacement_folks_test_case_test_method, self);
#line 29 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "simple equality", _email_field_details_tests_test_simple_equality_folks_test_case_test_method, self);
#line 30 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "parameter equality", _email_field_details_tests_test_params_equality_folks_test_case_test_method, self);
#line 31 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "ImFieldDetails equality", _email_field_details_tests_test_im_field_details_equality_folks_test_case_test_method, self);
#line 33 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "RoleFieldDetails equality", _email_field_details_tests_test_role_field_details_equality_folks_test_case_test_method, self);
#line 35 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "Generic AFD handling", _email_field_details_tests_test_generic_afd_handling_folks_test_case_test_method, self);
#line 25 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	return self;
#line 145 "abstract-field-details.c"
}


EmailFieldDetailsTests* email_field_details_tests_new (void) {
#line 25 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	return email_field_details_tests_construct (TYPE_EMAIL_FIELD_DETAILS_TESTS);
#line 152 "abstract-field-details.c"
}


static void _g_free0_ (gpointer var) {
#line 39 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	var = (g_free (var), NULL);
#line 159 "abstract-field-details.c"
}


static void _g_list_free__g_free0_ (GList* self) {
#line 39 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	g_list_foreach (self, (GFunc) _g_free0_, NULL);
#line 39 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	g_list_free (self);
#line 168 "abstract-field-details.c"
}


void email_field_details_tests_test_param_replacement (EmailFieldDetailsTests* self) {
	gchar* param_name = NULL;
	gchar* _tmp0_ = NULL;
	gchar** values_1 = NULL;
	gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	gchar** _tmp4_ = NULL;
	gint values_1_length1 = 0;
	gint _values_1_size_ = 0;
	gchar** values_2 = NULL;
	gchar* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
	gchar** _tmp7_ = NULL;
	gint values_2_length1 = 0;
	gint _values_2_size_ = 0;
	FolksEmailFieldDetails* details = NULL;
	GeeCollection* values = NULL;
	const gchar* _tmp8_ = NULL;
	FolksEmailFieldDetails* _tmp9_ = NULL;
	gchar** _tmp10_ = NULL;
	gint _tmp10__length1 = 0;
	FolksEmailFieldDetails* _tmp15_ = NULL;
	const gchar* _tmp16_ = NULL;
	GeeCollection* _tmp17_ = NULL;
	GeeCollection* _tmp18_ = NULL;
	gint _tmp19_ = 0;
	gint _tmp20_ = 0;
	gchar** _tmp21_ = NULL;
	gint _tmp21__length1 = 0;
	gchar** _tmp22_ = NULL;
	gint _tmp22__length1 = 0;
	FolksEmailFieldDetails* _tmp27_ = NULL;
	const gchar* _tmp28_ = NULL;
	gchar** _tmp29_ = NULL;
	gint _tmp29__length1 = 0;
	const gchar* _tmp30_ = NULL;
	FolksEmailFieldDetails* _tmp31_ = NULL;
	const gchar* _tmp32_ = NULL;
	GeeCollection* _tmp33_ = NULL;
	GeeCollection* _tmp34_ = NULL;
	gint _tmp35_ = 0;
	gint _tmp36_ = 0;
	GeeCollection* _tmp37_ = NULL;
	gchar** _tmp38_ = NULL;
	gint _tmp38__length1 = 0;
	const gchar* _tmp39_ = NULL;
	gboolean _tmp40_ = FALSE;
	FolksEmailFieldDetails* _tmp41_ = NULL;
	const gchar* _tmp42_ = NULL;
	FolksEmailFieldDetails* _tmp43_ = NULL;
	const gchar* _tmp44_ = NULL;
	GeeCollection* _tmp45_ = NULL;
	GeeCollection* _tmp46_ = NULL;
	gchar** _tmp47_ = NULL;
	gint _tmp47__length1 = 0;
	GList* values_2_list = NULL;
	gchar** _tmp52_ = NULL;
	gint _tmp52__length1 = 0;
	GeeHashMultiMap* param_table = NULL;
	GeeHashMultiMap* _tmp56_ = NULL;
	GList* _tmp57_ = NULL;
	FolksEmailFieldDetails* _tmp62_ = NULL;
	GeeHashMultiMap* _tmp63_ = NULL;
	FolksEmailFieldDetails* _tmp64_ = NULL;
	const gchar* _tmp65_ = NULL;
	GeeCollection* _tmp66_ = NULL;
	GeeCollection* _tmp67_ = NULL;
	gint _tmp68_ = 0;
	gint _tmp69_ = 0;
	gchar** _tmp70_ = NULL;
	gint _tmp70__length1 = 0;
	gchar** _tmp71_ = NULL;
	gint _tmp71__length1 = 0;
	gchar** _tmp72_ = NULL;
	gint _tmp72__length1 = 0;
	gchar** _tmp77_ = NULL;
	gint _tmp77__length1 = 0;
#line 39 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	g_return_if_fail (self != NULL);
#line 41 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp0_ = g_strdup ("metasyntactic-variables");
#line 41 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	param_name = _tmp0_;
#line 42 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp1_ = g_strdup ("foo");
#line 42 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp2_ = g_strdup ("bar");
#line 42 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp3_ = g_strdup ("baz");
#line 42 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp4_ = g_new0 (gchar*, 3 + 1);
#line 42 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp4_[0] = _tmp1_;
#line 42 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp4_[1] = _tmp2_;
#line 42 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp4_[2] = _tmp3_;
#line 42 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	values_1 = _tmp4_;
#line 42 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	values_1_length1 = 3;
#line 42 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_values_1_size_ = values_1_length1;
#line 43 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp5_ = g_strdup ("qux");
#line 43 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp6_ = g_strdup ("quxx");
#line 43 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp7_ = g_new0 (gchar*, 2 + 1);
#line 43 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp7_[0] = _tmp5_;
#line 43 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp7_[1] = _tmp6_;
#line 43 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	values_2 = _tmp7_;
#line 43 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	values_2_length1 = 2;
#line 43 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_values_2_size_ = values_2_length1;
#line 47 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp8_ = param_name;
#line 47 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp9_ = folks_email_field_details_new (_tmp8_, NULL);
#line 47 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_g_object_unref0 (details);
#line 47 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	details = _tmp9_;
#line 49 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp10_ = values_1;
#line 49 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp10__length1 = values_1_length1;
#line 304 "abstract-field-details.c"
	{
		gchar** val_collection = NULL;
		gint val_collection_length1 = 0;
		gint _val_collection_size_ = 0;
		gint val_it = 0;
#line 49 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
		val_collection = _tmp10_;
#line 49 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
		val_collection_length1 = _tmp10__length1;
#line 49 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
		for (val_it = 0; val_it < _tmp10__length1; val_it = val_it + 1) {
#line 316 "abstract-field-details.c"
			gchar* _tmp11_ = NULL;
			gchar* val = NULL;
#line 49 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
			_tmp11_ = g_strdup (val_collection[val_it]);
#line 49 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
			val = _tmp11_;
#line 323 "abstract-field-details.c"
			{
				FolksEmailFieldDetails* _tmp12_ = NULL;
				const gchar* _tmp13_ = NULL;
				const gchar* _tmp14_ = NULL;
#line 50 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
				_tmp12_ = details;
#line 50 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
				_tmp13_ = param_name;
#line 50 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
				_tmp14_ = val;
#line 50 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
				folks_abstract_field_details_add_parameter ((FolksAbstractFieldDetails*) _tmp12_, _tmp13_, _tmp14_);
#line 49 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
				_g_free0 (val);
#line 338 "abstract-field-details.c"
			}
		}
	}
#line 53 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp15_ = details;
#line 53 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp16_ = param_name;
#line 53 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp17_ = folks_abstract_field_details_get_parameter_values ((FolksAbstractFieldDetails*) _tmp15_, _tmp16_);
#line 53 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_g_object_unref0 (values);
#line 53 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	values = _tmp17_;
#line 54 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp18_ = values;
#line 54 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp19_ = gee_collection_get_size (_tmp18_);
#line 54 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp20_ = _tmp19_;
#line 54 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp21_ = values_1;
#line 54 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp21__length1 = values_1_length1;
#line 54 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_vala_assert (_tmp20_ == _tmp21__length1, "values.size == values_1.length");
#line 55 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp22_ = values_1;
#line 55 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp22__length1 = values_1_length1;
#line 368 "abstract-field-details.c"
	{
		gchar** val_collection = NULL;
		gint val_collection_length1 = 0;
		gint _val_collection_size_ = 0;
		gint val_it = 0;
#line 55 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
		val_collection = _tmp22_;
#line 55 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
		val_collection_length1 = _tmp22__length1;
#line 55 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
		for (val_it = 0; val_it < _tmp22__length1; val_it = val_it + 1) {
#line 380 "abstract-field-details.c"
			gchar* _tmp23_ = NULL;
			gchar* val = NULL;
#line 55 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
			_tmp23_ = g_strdup (val_collection[val_it]);
#line 55 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
			val = _tmp23_;
#line 387 "abstract-field-details.c"
			{
				GeeCollection* _tmp24_ = NULL;
				const gchar* _tmp25_ = NULL;
				gboolean _tmp26_ = FALSE;
#line 56 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
				_tmp24_ = values;
#line 56 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
				_tmp25_ = val;
#line 56 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
				_tmp26_ = gee_collection_contains (_tmp24_, _tmp25_);
#line 56 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
				_vala_assert (_tmp26_, "values.contains (val)");
#line 55 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
				_g_free0 (val);
#line 402 "abstract-field-details.c"
			}
		}
	}
#line 59 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp27_ = details;
#line 59 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp28_ = param_name;
#line 59 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp29_ = values_2;
#line 59 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp29__length1 = values_2_length1;
#line 59 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp30_ = _tmp29_[0];
#line 59 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	folks_abstract_field_details_set_parameter ((FolksAbstractFieldDetails*) _tmp27_, _tmp28_, _tmp30_);
#line 60 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp31_ = details;
#line 60 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp32_ = param_name;
#line 60 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp33_ = folks_abstract_field_details_get_parameter_values ((FolksAbstractFieldDetails*) _tmp31_, _tmp32_);
#line 60 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_g_object_unref0 (values);
#line 60 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	values = _tmp33_;
#line 61 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp34_ = values;
#line 61 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp35_ = gee_collection_get_size (_tmp34_);
#line 61 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp36_ = _tmp35_;
#line 61 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_vala_assert (_tmp36_ == 1, "values.size == 1");
#line 62 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp37_ = values;
#line 62 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp38_ = values_2;
#line 62 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp38__length1 = values_2_length1;
#line 62 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp39_ = _tmp38_[0];
#line 62 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp40_ = gee_collection_contains (_tmp37_, _tmp39_);
#line 62 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_vala_assert (_tmp40_, "values.contains (values_2[0])");
#line 65 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp41_ = details;
#line 65 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp42_ = param_name;
#line 65 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	folks_abstract_field_details_remove_parameter_all ((FolksAbstractFieldDetails*) _tmp41_, _tmp42_);
#line 66 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp43_ = details;
#line 66 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp44_ = param_name;
#line 66 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp45_ = folks_abstract_field_details_get_parameter_values ((FolksAbstractFieldDetails*) _tmp43_, _tmp44_);
#line 66 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_g_object_unref0 (values);
#line 66 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	values = _tmp45_;
#line 67 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp46_ = values;
#line 67 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_vala_assert (_tmp46_ == NULL, "values == null");
#line 70 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp47_ = values_1;
#line 70 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp47__length1 = values_1_length1;
#line 472 "abstract-field-details.c"
	{
		gchar** val_collection = NULL;
		gint val_collection_length1 = 0;
		gint _val_collection_size_ = 0;
		gint val_it = 0;
#line 70 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
		val_collection = _tmp47_;
#line 70 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
		val_collection_length1 = _tmp47__length1;
#line 70 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
		for (val_it = 0; val_it < _tmp47__length1; val_it = val_it + 1) {
#line 484 "abstract-field-details.c"
			gchar* _tmp48_ = NULL;
			gchar* val = NULL;
#line 70 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
			_tmp48_ = g_strdup (val_collection[val_it]);
#line 70 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
			val = _tmp48_;
#line 491 "abstract-field-details.c"
			{
				FolksEmailFieldDetails* _tmp49_ = NULL;
				const gchar* _tmp50_ = NULL;
				const gchar* _tmp51_ = NULL;
#line 71 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
				_tmp49_ = details;
#line 71 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
				_tmp50_ = param_name;
#line 71 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
				_tmp51_ = val;
#line 71 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
				folks_abstract_field_details_add_parameter ((FolksAbstractFieldDetails*) _tmp49_, _tmp50_, _tmp51_);
#line 70 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
				_g_free0 (val);
#line 506 "abstract-field-details.c"
			}
		}
	}
#line 73 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	values_2_list = NULL;
#line 74 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp52_ = values_2;
#line 74 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp52__length1 = values_2_length1;
#line 516 "abstract-field-details.c"
	{
		gchar** val_collection = NULL;
		gint val_collection_length1 = 0;
		gint _val_collection_size_ = 0;
		gint val_it = 0;
#line 74 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
		val_collection = _tmp52_;
#line 74 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
		val_collection_length1 = _tmp52__length1;
#line 74 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
		for (val_it = 0; val_it < _tmp52__length1; val_it = val_it + 1) {
#line 528 "abstract-field-details.c"
			gchar* _tmp53_ = NULL;
			gchar* val = NULL;
#line 74 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
			_tmp53_ = g_strdup (val_collection[val_it]);
#line 74 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
			val = _tmp53_;
#line 535 "abstract-field-details.c"
			{
				const gchar* _tmp54_ = NULL;
				gchar* _tmp55_ = NULL;
#line 75 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
				_tmp54_ = val;
#line 75 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
				_tmp55_ = g_strdup (_tmp54_);
#line 75 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
				values_2_list = g_list_append (values_2_list, _tmp55_);
#line 74 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
				_g_free0 (val);
#line 547 "abstract-field-details.c"
			}
		}
	}
#line 77 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp56_ = gee_hash_multi_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 77 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	param_table = _tmp56_;
#line 78 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp57_ = values_2_list;
#line 557 "abstract-field-details.c"
	{
		GList* val_collection = NULL;
		GList* val_it = NULL;
#line 78 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
		val_collection = _tmp57_;
#line 78 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
		for (val_it = val_collection; val_it != NULL; val_it = val_it->next) {
#line 565 "abstract-field-details.c"
			gchar* _tmp58_ = NULL;
			gchar* val = NULL;
#line 78 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
			_tmp58_ = g_strdup ((const gchar*) val_it->data);
#line 78 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
			val = _tmp58_;
#line 572 "abstract-field-details.c"
			{
				GeeHashMultiMap* _tmp59_ = NULL;
				const gchar* _tmp60_ = NULL;
				const gchar* _tmp61_ = NULL;
#line 79 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
				_tmp59_ = param_table;
#line 79 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
				_tmp60_ = param_name;
#line 79 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
				_tmp61_ = val;
#line 79 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
				gee_multi_map_set ((GeeMultiMap*) _tmp59_, _tmp60_, _tmp61_);
#line 78 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
				_g_free0 (val);
#line 587 "abstract-field-details.c"
			}
		}
	}
#line 81 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp62_ = details;
#line 81 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp63_ = param_table;
#line 81 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	folks_abstract_field_details_extend_parameters ((FolksAbstractFieldDetails*) _tmp62_, (GeeMultiMap*) _tmp63_);
#line 82 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp64_ = details;
#line 82 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp65_ = param_name;
#line 82 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp66_ = folks_abstract_field_details_get_parameter_values ((FolksAbstractFieldDetails*) _tmp64_, _tmp65_);
#line 82 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_g_object_unref0 (values);
#line 82 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	values = _tmp66_;
#line 83 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp67_ = values;
#line 83 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp68_ = gee_collection_get_size (_tmp67_);
#line 83 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp69_ = _tmp68_;
#line 83 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp70_ = values_1;
#line 83 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp70__length1 = values_1_length1;
#line 83 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp71_ = values_2;
#line 83 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp71__length1 = values_2_length1;
#line 83 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_vala_assert (_tmp69_ == (_tmp70__length1 + _tmp71__length1), "values.size == (values_1.length + values_2.length)");
#line 84 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp72_ = values_1;
#line 84 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp72__length1 = values_1_length1;
#line 627 "abstract-field-details.c"
	{
		gchar** val_collection = NULL;
		gint val_collection_length1 = 0;
		gint _val_collection_size_ = 0;
		gint val_it = 0;
#line 84 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
		val_collection = _tmp72_;
#line 84 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
		val_collection_length1 = _tmp72__length1;
#line 84 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
		for (val_it = 0; val_it < _tmp72__length1; val_it = val_it + 1) {
#line 639 "abstract-field-details.c"
			gchar* _tmp73_ = NULL;
			gchar* val = NULL;
#line 84 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
			_tmp73_ = g_strdup (val_collection[val_it]);
#line 84 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
			val = _tmp73_;
#line 646 "abstract-field-details.c"
			{
				GeeCollection* _tmp74_ = NULL;
				const gchar* _tmp75_ = NULL;
				gboolean _tmp76_ = FALSE;
#line 85 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
				_tmp74_ = values;
#line 85 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
				_tmp75_ = val;
#line 85 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
				_tmp76_ = gee_collection_contains (_tmp74_, _tmp75_);
#line 85 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
				_vala_assert (_tmp76_, "values.contains (val)");
#line 84 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
				_g_free0 (val);
#line 661 "abstract-field-details.c"
			}
		}
	}
#line 86 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp77_ = values_2;
#line 86 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp77__length1 = values_2_length1;
#line 669 "abstract-field-details.c"
	{
		gchar** val_collection = NULL;
		gint val_collection_length1 = 0;
		gint _val_collection_size_ = 0;
		gint val_it = 0;
#line 86 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
		val_collection = _tmp77_;
#line 86 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
		val_collection_length1 = _tmp77__length1;
#line 86 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
		for (val_it = 0; val_it < _tmp77__length1; val_it = val_it + 1) {
#line 681 "abstract-field-details.c"
			gchar* _tmp78_ = NULL;
			gchar* val = NULL;
#line 86 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
			_tmp78_ = g_strdup (val_collection[val_it]);
#line 86 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
			val = _tmp78_;
#line 688 "abstract-field-details.c"
			{
				GeeCollection* _tmp79_ = NULL;
				const gchar* _tmp80_ = NULL;
				gboolean _tmp81_ = FALSE;
#line 87 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
				_tmp79_ = values;
#line 87 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
				_tmp80_ = val;
#line 87 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
				_tmp81_ = gee_collection_contains (_tmp79_, _tmp80_);
#line 87 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
				_vala_assert (_tmp81_, "values.contains (val)");
#line 86 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
				_g_free0 (val);
#line 703 "abstract-field-details.c"
			}
		}
	}
#line 39 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_g_object_unref0 (param_table);
#line 39 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	__g_list_free__g_free0_0 (values_2_list);
#line 39 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_g_object_unref0 (values);
#line 39 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_g_object_unref0 (details);
#line 39 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	values_2 = (_vala_array_free (values_2, values_2_length1, (GDestroyNotify) g_free), NULL);
#line 39 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	values_1 = (_vala_array_free (values_1, values_1_length1, (GDestroyNotify) g_free), NULL);
#line 39 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_g_free0 (param_name);
#line 721 "abstract-field-details.c"
}


void email_field_details_tests_test_simple_equality (EmailFieldDetailsTests* self) {
	FolksEmailFieldDetails* details_a_1 = NULL;
	FolksEmailFieldDetails* _tmp0_ = NULL;
	FolksEmailFieldDetails* details_a_2 = NULL;
	FolksEmailFieldDetails* _tmp1_ = NULL;
	FolksEmailFieldDetails* details_b_1 = NULL;
	FolksEmailFieldDetails* _tmp2_ = NULL;
	gboolean _tmp3_ = FALSE;
	gboolean _tmp4_ = FALSE;
	gboolean _tmp5_ = FALSE;
	gboolean _tmp6_ = FALSE;
#line 90 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	g_return_if_fail (self != NULL);
#line 92 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp0_ = folks_email_field_details_new ("foo", NULL);
#line 92 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	details_a_1 = _tmp0_;
#line 93 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp1_ = folks_email_field_details_new ("foo", NULL);
#line 93 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	details_a_2 = _tmp1_;
#line 94 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp2_ = folks_email_field_details_new ("bar", NULL);
#line 94 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	details_b_1 = _tmp2_;
#line 97 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp3_ = folks_abstract_field_details_equal ((FolksAbstractFieldDetails*) details_a_1, (FolksAbstractFieldDetails*) details_a_2);
#line 97 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_vala_assert (_tmp3_, "details_a_1.equal (details_a_2)");
#line 98 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp4_ = folks_abstract_field_details_equal ((FolksAbstractFieldDetails*) details_a_1, (FolksAbstractFieldDetails*) details_b_1);
#line 98 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_vala_assert (!_tmp4_, "!details_a_1.equal (details_b_1)");
#line 99 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp5_ = folks_abstract_field_details_equal ((FolksAbstractFieldDetails*) details_b_1, (FolksAbstractFieldDetails*) details_a_1);
#line 99 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_vala_assert (!_tmp5_, "!details_b_1.equal (details_a_1)");
#line 100 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp6_ = folks_abstract_field_details_equal ((FolksAbstractFieldDetails*) details_b_1, (FolksAbstractFieldDetails*) details_a_2);
#line 100 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_vala_assert (!_tmp6_, "!details_b_1.equal (details_a_2)");
#line 90 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_g_object_unref0 (details_b_1);
#line 90 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_g_object_unref0 (details_a_2);
#line 90 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_g_object_unref0 (details_a_1);
#line 772 "abstract-field-details.c"
}


void email_field_details_tests_test_params_equality (EmailFieldDetailsTests* self) {
	FolksEmailFieldDetails* details_a_1 = NULL;
	FolksEmailFieldDetails* _tmp0_ = NULL;
	FolksEmailFieldDetails* details_a_2 = NULL;
	FolksEmailFieldDetails* _tmp1_ = NULL;
	GeeHashMultiMap* parameters = NULL;
	GeeHashMultiMap* _tmp2_ = NULL;
	GeeHashMultiMap* _tmp3_ = NULL;
	GeeHashMultiMap* _tmp4_ = NULL;
	GeeHashMultiMap* _tmp5_ = NULL;
	FolksEmailFieldDetails* _tmp6_ = NULL;
	GeeHashMultiMap* _tmp7_ = NULL;
	FolksEmailFieldDetails* _tmp29_ = NULL;
	FolksEmailFieldDetails* _tmp30_ = NULL;
	gboolean _tmp31_ = FALSE;
	FolksEmailFieldDetails* _tmp32_ = NULL;
	FolksEmailFieldDetails* _tmp33_ = NULL;
	FolksEmailFieldDetails* _tmp34_ = NULL;
	gboolean _tmp35_ = FALSE;
	FolksEmailFieldDetails* _tmp36_ = NULL;
	FolksEmailFieldDetails* _tmp37_ = NULL;
	FolksEmailFieldDetails* _tmp38_ = NULL;
	gboolean _tmp39_ = FALSE;
	FolksEmailFieldDetails* _tmp40_ = NULL;
	FolksEmailFieldDetails* _tmp41_ = NULL;
	FolksEmailFieldDetails* _tmp42_ = NULL;
	gboolean _tmp43_ = FALSE;
	FolksEmailFieldDetails* _tmp44_ = NULL;
	FolksEmailFieldDetails* _tmp45_ = NULL;
	FolksEmailFieldDetails* _tmp46_ = NULL;
	gboolean _tmp47_ = FALSE;
	FolksEmailFieldDetails* _tmp48_ = NULL;
	GeeMultiMap* _tmp49_ = NULL;
	GeeMultiMap* _tmp50_ = NULL;
	FolksEmailFieldDetails* _tmp51_ = NULL;
	FolksEmailFieldDetails* _tmp52_ = NULL;
	gboolean _tmp53_ = FALSE;
	FolksEmailFieldDetails* _tmp54_ = NULL;
	GeeMultiMap* _tmp55_ = NULL;
	GeeMultiMap* _tmp56_ = NULL;
	FolksEmailFieldDetails* _tmp57_ = NULL;
	FolksEmailFieldDetails* _tmp58_ = NULL;
	gboolean _tmp59_ = FALSE;
#line 103 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	g_return_if_fail (self != NULL);
#line 105 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp0_ = folks_email_field_details_new ("foo", NULL);
#line 105 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	details_a_1 = _tmp0_;
#line 106 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp1_ = folks_email_field_details_new ("foo", NULL);
#line 106 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	details_a_2 = _tmp1_;
#line 110 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp2_ = gee_hash_multi_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 110 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	parameters = _tmp2_;
#line 111 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp3_ = parameters;
#line 111 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	gee_multi_map_set ((GeeMultiMap*) _tmp3_, "bar", "baz");
#line 112 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp4_ = parameters;
#line 112 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	gee_multi_map_set ((GeeMultiMap*) _tmp4_, "qux", "quux");
#line 113 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp5_ = parameters;
#line 113 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	gee_multi_map_set ((GeeMultiMap*) _tmp5_, "qux", "quuux");
#line 114 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp6_ = details_a_1;
#line 114 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp7_ = parameters;
#line 114 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	folks_abstract_field_details_set_parameters ((FolksAbstractFieldDetails*) _tmp6_, (GeeMultiMap*) _tmp7_);
#line 851 "abstract-field-details.c"
	{
		GeeIterator* _param_it = NULL;
		GeeHashMultiMap* _tmp8_ = NULL;
		GeeSet* _tmp9_ = NULL;
		GeeSet* _tmp10_ = NULL;
		GeeIterator* _tmp11_ = NULL;
		GeeIterator* _tmp12_ = NULL;
#line 116 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
		_tmp8_ = parameters;
#line 116 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
		_tmp9_ = gee_multi_map_get_keys ((GeeMultiMap*) _tmp8_);
#line 116 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
		_tmp10_ = _tmp9_;
#line 116 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
		_tmp11_ = gee_iterable_iterator ((GeeIterable*) _tmp10_);
#line 116 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
		_tmp12_ = _tmp11_;
#line 116 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
		_g_object_unref0 (_tmp10_);
#line 116 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
		_param_it = _tmp12_;
#line 116 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
		while (TRUE) {
#line 875 "abstract-field-details.c"
			GeeIterator* _tmp13_ = NULL;
			gboolean _tmp14_ = FALSE;
			gchar* param = NULL;
			GeeIterator* _tmp15_ = NULL;
			gpointer _tmp16_ = NULL;
			GeeCollection* values = NULL;
			GeeHashMultiMap* _tmp17_ = NULL;
			const gchar* _tmp18_ = NULL;
			GeeCollection* _tmp19_ = NULL;
#line 116 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
			_tmp13_ = _param_it;
#line 116 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
			_tmp14_ = gee_iterator_next (_tmp13_);
#line 116 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
			if (!_tmp14_) {
#line 116 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
				break;
#line 893 "abstract-field-details.c"
			}
#line 116 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
			_tmp15_ = _param_it;
#line 116 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
			_tmp16_ = gee_iterator_get (_tmp15_);
#line 116 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
			param = (gchar*) _tmp16_;
#line 118 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
			_tmp17_ = parameters;
#line 118 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
			_tmp18_ = param;
#line 118 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
			_tmp19_ = gee_multi_map_get ((GeeMultiMap*) _tmp17_, _tmp18_);
#line 118 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
			values = _tmp19_;
#line 909 "abstract-field-details.c"
			{
				GeeIterator* _value_it = NULL;
				GeeCollection* _tmp20_ = NULL;
				GeeIterator* _tmp21_ = NULL;
#line 119 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
				_tmp20_ = values;
#line 119 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
				_tmp21_ = gee_iterable_iterator ((GeeIterable*) _tmp20_);
#line 119 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
				_value_it = _tmp21_;
#line 119 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
				while (TRUE) {
#line 922 "abstract-field-details.c"
					GeeIterator* _tmp22_ = NULL;
					gboolean _tmp23_ = FALSE;
					gchar* value = NULL;
					GeeIterator* _tmp24_ = NULL;
					gpointer _tmp25_ = NULL;
					FolksEmailFieldDetails* _tmp26_ = NULL;
					const gchar* _tmp27_ = NULL;
					const gchar* _tmp28_ = NULL;
#line 119 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
					_tmp22_ = _value_it;
#line 119 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
					_tmp23_ = gee_iterator_next (_tmp22_);
#line 119 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
					if (!_tmp23_) {
#line 119 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
						break;
#line 939 "abstract-field-details.c"
					}
#line 119 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
					_tmp24_ = _value_it;
#line 119 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
					_tmp25_ = gee_iterator_get (_tmp24_);
#line 119 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
					value = (gchar*) _tmp25_;
#line 120 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
					_tmp26_ = details_a_2;
#line 120 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
					_tmp27_ = param;
#line 120 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
					_tmp28_ = value;
#line 120 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
					folks_abstract_field_details_add_parameter ((FolksAbstractFieldDetails*) _tmp26_, _tmp27_, _tmp28_);
#line 119 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
					_g_free0 (value);
#line 957 "abstract-field-details.c"
				}
#line 119 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
				_g_object_unref0 (_value_it);
#line 961 "abstract-field-details.c"
			}
#line 116 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
			_g_object_unref0 (values);
#line 116 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
			_g_free0 (param);
#line 967 "abstract-field-details.c"
		}
#line 116 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
		_g_object_unref0 (_param_it);
#line 971 "abstract-field-details.c"
	}
#line 123 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp29_ = details_a_1;
#line 123 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp30_ = details_a_2;
#line 123 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp31_ = folks_abstract_field_details_equal ((FolksAbstractFieldDetails*) _tmp29_, (FolksAbstractFieldDetails*) _tmp30_);
#line 123 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_vala_assert (_tmp31_, "details_a_1.equal (details_a_2)");
#line 126 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp32_ = details_a_2;
#line 126 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	folks_abstract_field_details_add_parameter ((FolksAbstractFieldDetails*) _tmp32_, "bar", "baz");
#line 127 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp33_ = details_a_1;
#line 127 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp34_ = details_a_2;
#line 127 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp35_ = folks_abstract_field_details_equal ((FolksAbstractFieldDetails*) _tmp33_, (FolksAbstractFieldDetails*) _tmp34_);
#line 127 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_vala_assert (_tmp35_, "details_a_1.equal (details_a_2)");
#line 130 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp36_ = details_a_2;
#line 130 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	folks_abstract_field_details_add_parameter ((FolksAbstractFieldDetails*) _tmp36_, "bar", "new");
#line 131 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp37_ = details_a_1;
#line 131 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp38_ = details_a_2;
#line 131 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp39_ = folks_abstract_field_details_equal ((FolksAbstractFieldDetails*) _tmp37_, (FolksAbstractFieldDetails*) _tmp38_);
#line 131 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_vala_assert (!_tmp39_, "!details_a_1.equal (details_a_2)");
#line 134 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp40_ = details_a_2;
#line 134 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	folks_abstract_field_details_set_parameter ((FolksAbstractFieldDetails*) _tmp40_, "bar", "baz");
#line 135 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp41_ = details_a_1;
#line 135 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp42_ = details_a_2;
#line 135 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp43_ = folks_abstract_field_details_equal ((FolksAbstractFieldDetails*) _tmp41_, (FolksAbstractFieldDetails*) _tmp42_);
#line 135 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_vala_assert (_tmp43_, "details_a_1.equal (details_a_2)");
#line 138 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp44_ = details_a_2;
#line 138 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	folks_abstract_field_details_add_parameter ((FolksAbstractFieldDetails*) _tmp44_, "bar", "new");
#line 139 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp45_ = details_a_1;
#line 139 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp46_ = details_a_2;
#line 139 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp47_ = folks_abstract_field_details_equal ((FolksAbstractFieldDetails*) _tmp45_, (FolksAbstractFieldDetails*) _tmp46_);
#line 139 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_vala_assert (!_tmp47_, "!details_a_1.equal (details_a_2)");
#line 142 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp48_ = details_a_2;
#line 142 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp49_ = folks_abstract_field_details_get_parameters ((FolksAbstractFieldDetails*) _tmp48_);
#line 142 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp50_ = _tmp49_;
#line 142 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	gee_multi_map_remove (_tmp50_, "bar", "new");
#line 143 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp51_ = details_a_1;
#line 143 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp52_ = details_a_2;
#line 143 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp53_ = folks_abstract_field_details_equal ((FolksAbstractFieldDetails*) _tmp51_, (FolksAbstractFieldDetails*) _tmp52_);
#line 143 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_vala_assert (_tmp53_, "details_a_1.equal (details_a_2)");
#line 146 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp54_ = details_a_2;
#line 146 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp55_ = folks_abstract_field_details_get_parameters ((FolksAbstractFieldDetails*) _tmp54_);
#line 146 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp56_ = _tmp55_;
#line 146 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	gee_multi_map_remove_all (_tmp56_, "bar");
#line 147 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp57_ = details_a_1;
#line 147 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp58_ = details_a_2;
#line 147 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp59_ = folks_abstract_field_details_equal ((FolksAbstractFieldDetails*) _tmp57_, (FolksAbstractFieldDetails*) _tmp58_);
#line 147 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_vala_assert (!_tmp59_, "!details_a_1.equal (details_a_2)");
#line 103 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_g_object_unref0 (parameters);
#line 103 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_g_object_unref0 (details_a_2);
#line 103 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_g_object_unref0 (details_a_1);
#line 1067 "abstract-field-details.c"
}


void email_field_details_tests_test_im_field_details_equality (EmailFieldDetailsTests* self) {
	FolksImFieldDetails* details_a_1 = NULL;
	FolksImFieldDetails* _tmp0_ = NULL;
	FolksImFieldDetails* details_a_2 = NULL;
	FolksImFieldDetails* _tmp1_ = NULL;
	FolksImFieldDetails* details_b_1 = NULL;
	FolksImFieldDetails* _tmp2_ = NULL;
	gboolean _tmp3_ = FALSE;
	gboolean _tmp4_ = FALSE;
	FolksEmailFieldDetails* details_c_1 = NULL;
	FolksEmailFieldDetails* _tmp5_ = NULL;
	gboolean _tmp6_ = FALSE;
#line 150 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	g_return_if_fail (self != NULL);
#line 152 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp0_ = folks_im_field_details_new ("foo@example.org", NULL);
#line 152 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	details_a_1 = _tmp0_;
#line 153 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp1_ = folks_im_field_details_new ("foo@example.org", NULL);
#line 153 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	details_a_2 = _tmp1_;
#line 154 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp2_ = folks_im_field_details_new ("bar@other.example.org", NULL);
#line 154 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	details_b_1 = _tmp2_;
#line 157 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp3_ = folks_abstract_field_details_equal ((FolksAbstractFieldDetails*) details_a_1, (FolksAbstractFieldDetails*) details_a_2);
#line 157 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_vala_assert (_tmp3_, "details_a_1.equal (details_a_2)");
#line 158 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp4_ = folks_abstract_field_details_equal ((FolksAbstractFieldDetails*) details_a_1, (FolksAbstractFieldDetails*) details_b_1);
#line 158 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_vala_assert (!_tmp4_, "!details_a_1.equal (details_b_1)");
#line 161 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp5_ = folks_email_field_details_new ("foo@example.org", NULL);
#line 161 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	details_c_1 = _tmp5_;
#line 162 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp6_ = folks_abstract_field_details_equal ((FolksAbstractFieldDetails*) details_a_1, (FolksAbstractFieldDetails*) details_c_1);
#line 162 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_vala_assert (!_tmp6_, "!details_a_1.equal (details_c_1)");
#line 150 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_g_object_unref0 (details_c_1);
#line 150 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_g_object_unref0 (details_b_1);
#line 150 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_g_object_unref0 (details_a_2);
#line 150 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_g_object_unref0 (details_a_1);
#line 1121 "abstract-field-details.c"
}


void email_field_details_tests_test_role_field_details_equality (EmailFieldDetailsTests* self) {
	FolksRoleFieldDetails* details_a_1 = NULL;
	FolksRole* _tmp0_ = NULL;
	FolksRole* _tmp1_ = NULL;
	FolksRoleFieldDetails* _tmp2_ = NULL;
	FolksRoleFieldDetails* _tmp3_ = NULL;
	FolksRoleFieldDetails* details_a_2 = NULL;
	FolksRole* _tmp4_ = NULL;
	FolksRole* _tmp5_ = NULL;
	FolksRoleFieldDetails* _tmp6_ = NULL;
	FolksRoleFieldDetails* _tmp7_ = NULL;
	FolksRoleFieldDetails* details_b_1 = NULL;
	FolksRole* _tmp8_ = NULL;
	FolksRole* _tmp9_ = NULL;
	FolksRoleFieldDetails* _tmp10_ = NULL;
	FolksRoleFieldDetails* _tmp11_ = NULL;
	gboolean _tmp12_ = FALSE;
	gboolean _tmp13_ = FALSE;
#line 165 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	g_return_if_fail (self != NULL);
#line 167 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp0_ = folks_role_new ("Captain", "Obvious Corp.", NULL);
#line 167 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp1_ = _tmp0_;
#line 167 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp2_ = folks_role_field_details_new (_tmp1_, NULL);
#line 167 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp3_ = _tmp2_;
#line 167 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_g_object_unref0 (_tmp1_);
#line 167 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	details_a_1 = _tmp3_;
#line 169 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp4_ = folks_role_new ("Captain", "Obvious Corp.", NULL);
#line 169 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp5_ = _tmp4_;
#line 169 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp6_ = folks_role_field_details_new (_tmp5_, NULL);
#line 169 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp7_ = _tmp6_;
#line 169 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_g_object_unref0 (_tmp5_);
#line 169 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	details_a_2 = _tmp7_;
#line 171 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp8_ = folks_role_new ("Flunkie", "Obvious Corp.", NULL);
#line 171 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp9_ = _tmp8_;
#line 171 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp10_ = folks_role_field_details_new (_tmp9_, NULL);
#line 171 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp11_ = _tmp10_;
#line 171 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_g_object_unref0 (_tmp9_);
#line 171 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	details_b_1 = _tmp11_;
#line 175 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp12_ = folks_abstract_field_details_equal ((FolksAbstractFieldDetails*) details_a_1, (FolksAbstractFieldDetails*) details_a_2);
#line 175 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_vala_assert (_tmp12_, "details_a_1.equal (details_a_2)");
#line 176 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp13_ = folks_abstract_field_details_equal ((FolksAbstractFieldDetails*) details_a_1, (FolksAbstractFieldDetails*) details_b_1);
#line 176 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_vala_assert (!_tmp13_, "!details_a_1.equal (details_b_1)");
#line 165 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_g_object_unref0 (details_b_1);
#line 165 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_g_object_unref0 (details_a_2);
#line 165 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_g_object_unref0 (details_a_1);
#line 1195 "abstract-field-details.c"
}


void email_field_details_tests_test_generic_afd_handling (EmailFieldDetailsTests* self) {
	FolksAbstractFieldDetails* afd = NULL;
	FolksEmailFieldDetails* _tmp0_ = NULL;
	FolksAbstractFieldDetails* _tmp1_ = NULL;
	GType _tmp2_ = 0UL;
	gboolean _tmp3_ = FALSE;
	FolksAbstractFieldDetails* _tmp4_ = NULL;
	GType _tmp5_ = 0UL;
	GType _tmp6_ = 0UL;
	FolksImFieldDetails* _tmp7_ = NULL;
	FolksAbstractFieldDetails* _tmp8_ = NULL;
	GType _tmp9_ = 0UL;
	gboolean _tmp10_ = FALSE;
	FolksAbstractFieldDetails* _tmp11_ = NULL;
	GType _tmp12_ = 0UL;
	GType _tmp13_ = 0UL;
	FolksNoteFieldDetails* _tmp14_ = NULL;
	FolksAbstractFieldDetails* _tmp15_ = NULL;
	GType _tmp16_ = 0UL;
	gboolean _tmp17_ = FALSE;
	FolksAbstractFieldDetails* _tmp18_ = NULL;
	GType _tmp19_ = 0UL;
	GType _tmp20_ = 0UL;
	FolksPhoneFieldDetails* _tmp21_ = NULL;
	FolksAbstractFieldDetails* _tmp22_ = NULL;
	GType _tmp23_ = 0UL;
	gboolean _tmp24_ = FALSE;
	FolksAbstractFieldDetails* _tmp25_ = NULL;
	GType _tmp26_ = 0UL;
	GType _tmp27_ = 0UL;
	FolksPostalAddress* _tmp28_ = NULL;
	FolksPostalAddress* _tmp29_ = NULL;
	FolksPostalAddressFieldDetails* _tmp30_ = NULL;
	FolksAbstractFieldDetails* _tmp31_ = NULL;
	GType _tmp32_ = 0UL;
	gboolean _tmp33_ = FALSE;
	FolksAbstractFieldDetails* _tmp34_ = NULL;
	GType _tmp35_ = 0UL;
	GType _tmp36_ = 0UL;
	FolksAbstractFieldDetails* _tmp37_ = NULL;
	GType _tmp38_ = 0UL;
	GType _tmp39_ = 0UL;
	FolksRole* _tmp40_ = NULL;
	FolksRole* _tmp41_ = NULL;
	FolksRoleFieldDetails* _tmp42_ = NULL;
	FolksAbstractFieldDetails* _tmp43_ = NULL;
	GType _tmp44_ = 0UL;
	gboolean _tmp45_ = FALSE;
	FolksAbstractFieldDetails* _tmp46_ = NULL;
	GType _tmp47_ = 0UL;
	GType _tmp48_ = 0UL;
	FolksAbstractFieldDetails* _tmp49_ = NULL;
	GType _tmp50_ = 0UL;
	GType _tmp51_ = 0UL;
	FolksUrlFieldDetails* _tmp52_ = NULL;
	FolksAbstractFieldDetails* _tmp53_ = NULL;
	GType _tmp54_ = 0UL;
	gboolean _tmp55_ = FALSE;
	FolksAbstractFieldDetails* _tmp56_ = NULL;
	GType _tmp57_ = 0UL;
	GType _tmp58_ = 0UL;
	FolksWebServiceFieldDetails* _tmp59_ = NULL;
	FolksAbstractFieldDetails* _tmp60_ = NULL;
	GType _tmp61_ = 0UL;
	gboolean _tmp62_ = FALSE;
	FolksAbstractFieldDetails* _tmp63_ = NULL;
	GType _tmp64_ = 0UL;
	GType _tmp65_ = 0UL;
#line 179 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	g_return_if_fail (self != NULL);
#line 183 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp0_ = folks_email_field_details_new ("foo@example.org", NULL);
#line 183 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_g_object_unref0 (afd);
#line 183 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	afd = (FolksAbstractFieldDetails*) _tmp0_;
#line 184 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp1_ = afd;
#line 184 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp2_ = G_TYPE_FROM_INSTANCE ((GObject*) _tmp1_);
#line 184 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp3_ = g_type_is_a (_tmp2_, FOLKS_TYPE_ABSTRACT_FIELD_DETAILS);
#line 184 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_vala_assert (_tmp3_, "afd.get_type ().is_a (typeof (AbstractFieldDetails))");
#line 185 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp4_ = afd;
#line 185 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp5_ = folks_abstract_field_details_get_value_type (_tmp4_);
#line 185 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp6_ = _tmp5_;
#line 185 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_vala_assert (_tmp6_ == G_TYPE_STRING, "afd.value_type == typeof (string)");
#line 187 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp7_ = folks_im_field_details_new ("bar@example.org", NULL);
#line 187 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_g_object_unref0 (afd);
#line 187 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	afd = (FolksAbstractFieldDetails*) _tmp7_;
#line 188 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp8_ = afd;
#line 188 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp9_ = G_TYPE_FROM_INSTANCE ((GObject*) _tmp8_);
#line 188 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp10_ = g_type_is_a (_tmp9_, FOLKS_TYPE_ABSTRACT_FIELD_DETAILS);
#line 188 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_vala_assert (_tmp10_, "afd.get_type ().is_a (typeof (AbstractFieldDetails))");
#line 189 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp11_ = afd;
#line 189 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp12_ = folks_abstract_field_details_get_value_type (_tmp11_);
#line 189 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp13_ = _tmp12_;
#line 189 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_vala_assert (_tmp13_ == G_TYPE_STRING, "afd.value_type == typeof (string)");
#line 191 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp14_ = folks_note_field_details_new ("Are you writing this down?", NULL, NULL);
#line 191 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_g_object_unref0 (afd);
#line 191 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	afd = (FolksAbstractFieldDetails*) _tmp14_;
#line 192 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp15_ = afd;
#line 192 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp16_ = G_TYPE_FROM_INSTANCE ((GObject*) _tmp15_);
#line 192 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp17_ = g_type_is_a (_tmp16_, FOLKS_TYPE_ABSTRACT_FIELD_DETAILS);
#line 192 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_vala_assert (_tmp17_, "afd.get_type ().is_a (typeof (AbstractFieldDetails))");
#line 193 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp18_ = afd;
#line 193 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp19_ = folks_abstract_field_details_get_value_type (_tmp18_);
#line 193 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp20_ = _tmp19_;
#line 193 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_vala_assert (_tmp20_ == G_TYPE_STRING, "afd.value_type == typeof (string)");
#line 195 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp21_ = folks_phone_field_details_new ("+19255551234", NULL);
#line 195 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_g_object_unref0 (afd);
#line 195 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	afd = (FolksAbstractFieldDetails*) _tmp21_;
#line 196 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp22_ = afd;
#line 196 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp23_ = G_TYPE_FROM_INSTANCE ((GObject*) _tmp22_);
#line 196 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp24_ = g_type_is_a (_tmp23_, FOLKS_TYPE_ABSTRACT_FIELD_DETAILS);
#line 196 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_vala_assert (_tmp24_, "afd.get_type ().is_a (typeof (AbstractFieldDetails))");
#line 197 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp25_ = afd;
#line 197 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp26_ = folks_abstract_field_details_get_value_type (_tmp25_);
#line 197 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp27_ = _tmp26_;
#line 197 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_vala_assert (_tmp27_ == G_TYPE_STRING, "afd.value_type == typeof (string)");
#line 199 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp28_ = folks_postal_address_new (NULL, NULL, "123 Streetly Way", "Cityville", "Cascadia", NULL, "USA", NULL, NULL);
#line 199 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp29_ = _tmp28_;
#line 199 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp30_ = folks_postal_address_field_details_new (_tmp29_, NULL);
#line 199 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_g_object_unref0 (afd);
#line 199 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	afd = (FolksAbstractFieldDetails*) _tmp30_;
#line 199 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_g_object_unref0 (_tmp29_);
#line 202 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp31_ = afd;
#line 202 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp32_ = G_TYPE_FROM_INSTANCE ((GObject*) _tmp31_);
#line 202 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp33_ = g_type_is_a (_tmp32_, FOLKS_TYPE_ABSTRACT_FIELD_DETAILS);
#line 202 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_vala_assert (_tmp33_, "afd.get_type ().is_a (typeof (AbstractFieldDetails))");
#line 203 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp34_ = afd;
#line 203 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp35_ = folks_abstract_field_details_get_value_type (_tmp34_);
#line 203 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp36_ = _tmp35_;
#line 203 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_vala_assert (_tmp36_ == FOLKS_TYPE_POSTAL_ADDRESS, "afd.value_type == typeof (PostalAddress)");
#line 204 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp37_ = afd;
#line 204 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp38_ = folks_abstract_field_details_get_value_type (_tmp37_);
#line 204 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp39_ = _tmp38_;
#line 204 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_vala_assert (_tmp39_ != G_TYPE_STRING, "afd.value_type != typeof (string)");
#line 206 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp40_ = folks_role_new ("Captain", "Obvious Corp.", NULL);
#line 206 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp41_ = _tmp40_;
#line 206 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp42_ = folks_role_field_details_new (_tmp41_, NULL);
#line 206 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_g_object_unref0 (afd);
#line 206 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	afd = (FolksAbstractFieldDetails*) _tmp42_;
#line 206 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_g_object_unref0 (_tmp41_);
#line 208 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp43_ = afd;
#line 208 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp44_ = G_TYPE_FROM_INSTANCE ((GObject*) _tmp43_);
#line 208 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp45_ = g_type_is_a (_tmp44_, FOLKS_TYPE_ABSTRACT_FIELD_DETAILS);
#line 208 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_vala_assert (_tmp45_, "afd.get_type ().is_a (typeof (AbstractFieldDetails))");
#line 209 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp46_ = afd;
#line 209 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp47_ = folks_abstract_field_details_get_value_type (_tmp46_);
#line 209 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp48_ = _tmp47_;
#line 209 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_vala_assert (_tmp48_ == FOLKS_TYPE_ROLE, "afd.value_type == typeof (Role)");
#line 210 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp49_ = afd;
#line 210 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp50_ = folks_abstract_field_details_get_value_type (_tmp49_);
#line 210 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp51_ = _tmp50_;
#line 210 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_vala_assert (_tmp51_ != G_TYPE_STRING, "afd.value_type != typeof (string)");
#line 212 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp52_ = folks_url_field_details_new ("http://other.side.of.nowhere", NULL);
#line 212 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_g_object_unref0 (afd);
#line 212 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	afd = (FolksAbstractFieldDetails*) _tmp52_;
#line 213 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp53_ = afd;
#line 213 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp54_ = G_TYPE_FROM_INSTANCE ((GObject*) _tmp53_);
#line 213 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp55_ = g_type_is_a (_tmp54_, FOLKS_TYPE_ABSTRACT_FIELD_DETAILS);
#line 213 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_vala_assert (_tmp55_, "afd.get_type ().is_a (typeof (AbstractFieldDetails))");
#line 214 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp56_ = afd;
#line 214 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp57_ = folks_abstract_field_details_get_value_type (_tmp56_);
#line 214 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp58_ = _tmp57_;
#line 214 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_vala_assert (_tmp58_ == G_TYPE_STRING, "afd.value_type == typeof (string)");
#line 216 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp59_ = folks_web_service_field_details_new ("bluebomber", NULL);
#line 216 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_g_object_unref0 (afd);
#line 216 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	afd = (FolksAbstractFieldDetails*) _tmp59_;
#line 217 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp60_ = afd;
#line 217 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp61_ = G_TYPE_FROM_INSTANCE ((GObject*) _tmp60_);
#line 217 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp62_ = g_type_is_a (_tmp61_, FOLKS_TYPE_ABSTRACT_FIELD_DETAILS);
#line 217 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_vala_assert (_tmp62_, "afd.get_type ().is_a (typeof (AbstractFieldDetails))");
#line 218 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp63_ = afd;
#line 218 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp64_ = folks_abstract_field_details_get_value_type (_tmp63_);
#line 218 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp65_ = _tmp64_;
#line 218 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_vala_assert (_tmp65_ == G_TYPE_STRING, "afd.value_type == typeof (string)");
#line 179 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_g_object_unref0 (afd);
#line 1475 "abstract-field-details.c"
}


static void email_field_details_tests_class_init (EmailFieldDetailsTestsClass * klass) {
#line 23 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	email_field_details_tests_parent_class = g_type_class_peek_parent (klass);
#line 1482 "abstract-field-details.c"
}


static void email_field_details_tests_instance_init (EmailFieldDetailsTests * self) {
}


GType email_field_details_tests_get_type (void) {
	static volatile gsize email_field_details_tests_type_id__volatile = 0;
	if (g_once_init_enter (&email_field_details_tests_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (EmailFieldDetailsTestsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) email_field_details_tests_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (EmailFieldDetailsTests), 0, (GInstanceInitFunc) email_field_details_tests_instance_init, NULL };
		GType email_field_details_tests_type_id;
		email_field_details_tests_type_id = g_type_register_static (FOLKS_TYPE_TEST_CASE, "EmailFieldDetailsTests", &g_define_type_info, 0);
		g_once_init_leave (&email_field_details_tests_type_id__volatile, email_field_details_tests_type_id);
	}
	return email_field_details_tests_type_id__volatile;
}


gint _vala_main (gchar** args, int args_length1) {
	gint result = 0;
	EmailFieldDetailsTests* tests = NULL;
	EmailFieldDetailsTests* _tmp0_ = NULL;
#line 224 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	g_test_init (&args_length1, &args, NULL);
#line 226 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_tmp0_ = email_field_details_tests_new ();
#line 226 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	tests = _tmp0_;
#line 227 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	folks_test_case_register ((FolksTestCase*) tests);
#line 228 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	g_test_run ();
#line 229 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	folks_test_case_final_tear_down ((FolksTestCase*) tests);
#line 231 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	result = 0;
#line 231 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	_g_object_unref0 (tests);
#line 231 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	return result;
#line 1524 "abstract-field-details.c"
}


int main (int argc, char ** argv) {
#if !GLIB_CHECK_VERSION (2,35,0)
	g_type_init ();
#endif
#line 222 "/opt/gnome3/source/folks/tests/folks/abstract-field-details.vala"
	return _vala_main (argv, argc);
#line 1534 "abstract-field-details.c"
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}



